/**********************************************************************
 * Copyright (c) 2005 David Linsin. All rights reserved. This
 * program and the accompanying materials are made available under the terms of
 * the Common Public License v1.0 which accompanies this distribution, and is
 * available at http://www.opensource.org/licenses/cpl1.0.php
 * 
 * Contributors: 
 * David Linsin (david@linsin.de)
 **********************************************************************/ 

package de.linsin.example.fit;

import java.math.BigDecimal;
import java.math.MathContext;

import de.linsin.example.drools.domain.Customer;
import de.linsin.example.drools.domain.Item;
import de.linsin.example.drools.domain.Register;
import de.linsin.example.drools.domain.ShoppingCart;
import fit.ColumnFixture;

/**
 * ColumnFixture which tests domain rules
 *
 * @author David Linsin
 * @version 0.1
 * @since 0.1
 */
public class DomainRulesFit extends ColumnFixture {
    
    /** row value of column item price */
    public double itemPrice;
    /** row value of column item name */
    public String itemName;
    /** row value of column on season sale */
    public boolean onSeasonSale;
    /** row value of column quantity */
    public int quantity;
    /** row value of column discount */
    public boolean discount;
    
    /**
     * Used to test domain rules with fit framework. Therefore the defined values 
     * of the website are wired together with the domain objects and the result, 
     * which represents the calculated total, is being returned 
     * 
     * @return double value representing the total amount
     * @throws Exception in case anything goes wrong
     */
    public double total() throws Exception {
       Item item = new Item(1, this.itemName, this.itemPrice, this.onSeasonSale);
       Customer customer = new Customer(22, new ShoppingCart(), "David Linsin", "CreditCard", this.discount);
       customer.getCart().addItem(item, this.quantity);
       BigDecimal total = new BigDecimal(new Register().determineTotal(customer).getTotal(), new MathContext(4));
       return total.doubleValue();
    }     
}

